libfprint/SOURCES/0122-fpi-ssm-Use-same-argument-names-of-header-file.patch
2021-09-09 20:12:48 +00:00

45 lines
1.5 KiB
Diff

From 3aea44e308637bfc8d32c751f9d50aa34e0f9229 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Marco=20Trevisan=20=28Trevi=C3=B1o=29?= <mail@3v1n0.net>
Date: Wed, 11 Dec 2019 20:07:59 +0100
Subject: [PATCH 122/181] fpi-ssm: Use same argument names of header file
So we can mute a Gtk-doc parser warning
---
libfprint/fpi-ssm.c | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/libfprint/fpi-ssm.c b/libfprint/fpi-ssm.c
index 8b3e4bd..0f3e6fb 100644
--- a/libfprint/fpi-ssm.c
+++ b/libfprint/fpi-ssm.c
@@ -115,7 +115,7 @@ struct _FpiSsm
* @dev: a #fp_dev fingerprint device
* @handler: the callback function
* @nr_states: the number of states
* @name: the name of the state machine (for debug purposes)
*
* Allocate a new ssm, with @nr_states states. The @handler callback
* will be called after each state transition.
@@ -126,7 +126,7 @@ FpiSsm *
fpi_ssm_new_full (FpDevice *dev,
FpiSsmHandlerCallback handler,
int nr_states,
- const char *name)
+ const char *machine_name)
{
FpiSsm *machine;
@@ -137,7 +137,7 @@ fpi_ssm_new_full (FpDevice *dev,
machine->handler = handler;
machine->nr_states = nr_states;
machine->dev = dev;
- machine->name = g_strdup (name);
+ machine->name = g_strdup (machine_name);
machine->completed = TRUE;
return machine;
}
@@ -115,7 +115,7 @@ struct _FpiSsm
* @handler: the callback function
* @nr_states: the number of states
- * @name: the name of the state machine (for debug purposes)
+ * @machine_name: the name of the state machine (for debug purposes)
*
* Allocate a new ssm, with @nr_states states. The @handler callback
--
2.24.1